@@ -1,5 +1,4 @@
 # SNMP::Info::CiscoStats
-# $Id$
 #
 # Changes since Version 0.7 Copyright (c) 2008-2009 Max Baker and SNMP::Info Developers
 # All rights reserved.
@@ -34,15 +33,16 @@
 package SNMP::Info::CiscoStats;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
 @SNMP::Info::CiscoStats::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::CiscoStats::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %MIBS %FUNCS %GLOBALS %MUNGE/;
+our ($VERSION, %MIBS, %FUNCS, %GLOBALS, %MUNGE);
 
-$VERSION = '3.65';
+$VERSION = '3.92';
 
 %MIBS = (
     'SNMPv2-MIB'            => 'sysDescr',
@@ -105,6 +105,15 @@ sub os {
 
     # order here matters - there are Catalysts that run IOS and have catalyst
     # in their description field, as well as Catalysts that run IOS-XE.
+    return 'ios-xe'   if ( $descr =~ /Denali/ );
+    return 'ios-xe'   if ( $descr =~ /Fuji/ );
+    return 'ios-xe'   if ( $descr =~ /Everest/ );
+    return 'ios-xe'   if ( $descr =~ /Gibraltar/ );
+    return 'ios-xe'   if ( $descr =~ /Amsterdam/ );
+    return 'ios-xe'   if ( $descr =~ /Bengaluru/ );
+    return 'ios-xe'   if ( $descr =~ /Cupertino/ );
+    return 'ios-xe'   if ( $descr =~ /Dublin/ );
+    return 'ios-xe'   if ( $descr =~ /IOSXE/ );
     return 'ios-xe'   if ( $descr =~ /IOS-XE/ );
     return 'ios-xr'   if ( $descr =~ /IOS XR/ );
     return 'ios'      if ( $descr =~ /IOS/ );
@@ -385,8 +394,6 @@ None.
 
 =back
 
-MIBs can be found at ftp://ftp.cisco.com/pub/mibs/v2/v2.tar.gz
-
 =head1 GLOBALS
 
 =over
