@@ -1,5 +1,4 @@
 # SNMP::Info::Layer3::Extreme - SNMP Interface to Extreme devices
-# $Id$
 #
 # Copyright (c) 2012 Eric Miller
 #
@@ -33,25 +32,24 @@
 package SNMP::Info::Layer3::Extreme;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer3;
 use SNMP::Info::MAU;
-use SNMP::Info::LLDP;
 use SNMP::Info::EDP;
 
 @SNMP::Info::Layer3::Extreme::ISA
-    = qw/SNMP::Info::Layer3 SNMP::Info::MAU SNMP::Info::LLDP
+    = qw/SNMP::Info::Layer3 SNMP::Info::MAU
     SNMP::Info::EDP Exporter/;
 @SNMP::Info::Layer3::Extreme::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %FUNCS %MIBS %MUNGE/;
+our ($VERSION, %GLOBALS, %FUNCS, %MIBS, %MUNGE);
 
-$VERSION = '3.65';
+$VERSION = '3.92';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
     %SNMP::Info::MAU::MIBS,
-    %SNMP::Info::LLDP::MIBS,
     %SNMP::Info::EDP::MIBS,
     'EXTREME-BASE-MIB'           => 'extremeAgent',
     'EXTREME-SYSTEM-MIB'         => 'extremeSystem',
@@ -64,7 +62,6 @@ $VERSION = '3.65';
 %GLOBALS = (
     %SNMP::Info::Layer3::GLOBALS,
     %SNMP::Info::MAU::GLOBALS,
-    %SNMP::Info::LLDP::GLOBALS,
     %SNMP::Info::EDP::GLOBALS,
     'serial1'        => 'extremeSystemID.0',
     'temp'           => 'extremeCurrentTemperature',
@@ -78,7 +75,6 @@ $VERSION = '3.65';
 %FUNCS = (
     %SNMP::Info::Layer3::FUNCS,
     %SNMP::Info::MAU::FUNCS,
-    %SNMP::Info::LLDP::FUNCS,
     %SNMP::Info::EDP::FUNCS,
     'fan_state' => 'extremeFanOperational',
     # EXTREME-FDB-MIB:extremeFdbMacFdbTable
@@ -119,7 +115,6 @@ $VERSION = '3.65';
     # Inherit all the built in munging
     %SNMP::Info::Layer3::MUNGE,
     %SNMP::Info::MAU::MUNGE,
-    %SNMP::Info::LLDP::MUNGE,
     %SNMP::Info::EDP::MUNGE,
     'ex_fw_mac'        => \&SNMP::Info::munge_mac,
     'ps1_status_old'   => \&munge_true_ok,
@@ -166,7 +161,6 @@ sub vendor {
 
 sub os {
     my $extreme = shift;
-
     my $desc = $extreme->description();
 
     if ( $desc =~ /xos/i ) {
@@ -307,8 +301,8 @@ sub _slot_factor {
 sub fw_mac {
     my $extreme = shift;
 
-    my $b = $extreme->SUPER::fw_mac();
-    return $b if (keys %$b);
+    my $fw_m = $extreme->SUPER::fw_mac();
+    return $fw_m if (keys %$fw_m);
 
     return $extreme->ex_fw_mac();
 }
@@ -316,8 +310,8 @@ sub fw_mac {
 sub fw_port {
     my $extreme = shift;
 
-    my $b = $extreme->SUPER::fw_port();
-    return $b if (keys %$b);
+    my $fw_p = $extreme->SUPER::fw_port();
+    return $fw_p if (keys %$fw_p);
 
     return $extreme->ex_fw_port();
 }
@@ -325,8 +319,8 @@ sub fw_port {
 sub fw_status {
     my $extreme   = shift;
 
-    my $b = $extreme->SUPER::fw_status();
-    return $b if (keys %$b);
+    my $fw_s = $extreme->SUPER::fw_status();
+    return $fw_s if (keys %$fw_s);
 
     return $extreme->ex_fw_status();
 }
@@ -892,7 +886,7 @@ Eric Miller, Bill Fenner
                           Debug       => 1,
                           DestHost    => 'myswitch',
                           Community   => 'public',
-                          Version     => 1
+                          Version     => 2
                         )
     or die "Can't connect to DestHost.\n";
 
@@ -905,11 +899,6 @@ Eric Miller, Bill Fenner
 Provides abstraction to the configuration information obtainable from an
 Extreme device through SNMP.
 
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above.
-
-my $extreme = new SNMP::Info::Layer3::Extreme(...);
-
 =head2 Inherited Classes
 
 =over
@@ -918,8 +907,6 @@ my $extreme = new SNMP::Info::Layer3::Extreme(...);
 
 =item SNMP::Info::MAU
 
-=item SNMP::Info::LLDP
-
 =item SNMP::Info::EDP
 
 =back
@@ -938,6 +925,8 @@ my $extreme = new SNMP::Info::Layer3::Extreme(...);
 
 =item F<EXTREME-POE-MIB>
 
+=item F<EXTREME-STP-EXTENSIONS-MIB>
+
 =item Inherited Classes' MIBs
 
 See classes listed above for their required MIBs.
@@ -956,11 +945,11 @@ Returns model type.  Checks $extreme->id() against the F<EXTREME-BASE-MIB>.
 
 =item $extreme->vendor()
 
-Returns extreme
+Returns C<extreme>
 
 =item $extreme->os()
 
-Returns extreme
+Returns C<xos> or C<extremeware> depending on description()
 
 =item $extreme->os_ver()
 
@@ -1012,10 +1001,6 @@ See documentation in L<SNMP::Info::Layer3/"GLOBALS"> for details.
 
 See documentation in L<SNMP::Info::MAU/"GLOBALS"> for details.
 
-=head2 Globals imported from SNMP::Info::LLDP
-
-See documentation in L<SNMP::Info::LLDP/"GLOBALS"> for details.
-
 =head2 Globals imported from SNMP::Info::EDP
 
 See documentation in L<SNMP::Info::EDP/"GLOBALS"> for details.
@@ -1226,10 +1211,6 @@ See documentation in L<SNMP::Info::Layer3/"TABLE METHODS"> for details.
 
 See documentation in L<SNMP::Info::MAU/"TABLE METHODS"> for details.
 
-=head2 Table Methods imported from SNMP::Info::LLDP
-
-See documentation in L<SNMP::Info::LLDP/"TABLE METHODS"> for details.
-
 =head2 Table Methods imported from SNMP::Info::EDP
 
 See documentation in L<SNMP::Info::EDP/"TABLE METHODS"> for details.
